@@ -146,7 +146,7 @@ public:
         coeffs /= k;
     }
 
-    bool operator== (point& p) const
+    bool operator== (const point& p) const
     {
         int i=0;
         const Coeff & coeffs = p.getCoefficients();
